@@ -1,10 +1,10 @@
-/* 
+/*
     This file is part of Rocs.
     Copyright 2011  Tomaz Canabrava <tomaz.canabrava@gmail.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of 
+    published by the Free Software Foundation; either version 2 of
     the License, or (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -19,5 +19,11 @@
 #include "Group.h"
 
 Group::Group(QObject *parent) : QObject(parent) {}
-void Group::setName(const QString& name){ Q_UNUSED(name);}
-const QString& Group::name() const{ return _name; }
+void Group::setName(const QString& name)
+{
+    Q_UNUSED(name);
+}
+const QString& Group::name() const
+{
+    return _name;
+}
